
rm(list=ls())

library(ProcData)
# load climate control data
data(cc_data)

# uncomment the following lines if ProcData is installed from CRAN
# library(keras)
# source("subtask.R")

################################################################
###           code chunk number 1: subtask analysis          ###
################################################################
### This code chunk demonstrates function subtask_analysis() ### 
################################################################

# perform subtask analysis on the action sequences of the first 100 processes
# nstart = 10 instructs function kmeans() to generate 10 random sets of initial cluster centers
cc_res <- subtask_analysis(cc_data$seqs$action_seqs[1:100], 
                           n_subtask=1:5, 
                           n_epoch = 20,
                           batch_size = 1,
                           verbose = T, 
                           nstart=10)

# save(cc_res, file="subtask_example_results.RData")
load("subtask_example_results.RData")

# plot the trace of loss for fitting the RNN-based action prediction model
plot(cc_res$loss_history[,2], type="l", ylab = "Loss", xlab="Epoch")

# plot the total within cluster sum of squences for diffient choices of number of clusters
plot(cc_res$tot.withinss, type="l", ylab="Total Within Cluster SS", xlab="Number of Clusters")

# selected number of subtasks (clusters)
cc_res$n_subtask

# 20 high relative frequency actions for cluster 1
sort(cc_res$relative_cluster_profiles[1,], decreasing = TRUE)[1:20] # IDLE
# 20 high relative frequency actions for cluster 2
sort(cc_res$relative_cluster_profiles[2,], decreasing = TRUE)[1:20] # EXPLORATION
# 20 high relative frequency actions for cluster 3
sort(cc_res$relative_cluster_profiles[3,], decreasing = TRUE)[1:20] # EFFECIENT Solving

# rename subtasks
cc_res$subtasks <- c("IDL", "EXP", "EFF")

# proportion of sequences with "varying one thing at a time" strategy
mean(sapply(cc_res$subtask_seqs, function(x) 3 %in% x))


####################################################################
###      code chunk number 2: plot subtask analysis results      ###
####################################################################
### This code chunk demonstrates plot.subtask(), the plot method ###
### of "subtask" objects                                         ### 
####################################################################


# plot results for sequence 2
plot(cc_res, type="individual", index=2)
# plot results for sequence 19
plot(cc_res, type="individual", index=19)
# plot results for sequence 20
plot(cc_res, type="individual", index=20)

# index can be a vector
# plot(cc_res, type="individual", index=c(2, 19, 20))

# plot subtask results for the entire dataset
plot(cc_res)

